pub struct ValueCachedQueue<Q> {
queue: Q,
value_cache: HashMap<u32, HoprBalance>,
}Expand description
Adapter for TicketQueue that caches the total ticket value per channel epoch.
The cache value is updated with each push and pop operation.
The total_value method
returns the cached value if available, otherwise it delegates to the underlying queue.
If min_index is provided, the cache is bypassed and the underlying queue is queried directly.
All other calls are simply delegated to the underlying queue.
The implementation uses hashbrown::HashMap for efficient key-value storage.
Fields
queue: Qvalue_cache: HashMap<u32, HoprBalance>Implementations
Sourceimpl<Q: TicketQueue> ValueCachedQueue<Q>
impl<Q: TicketQueue> ValueCachedQueue<Q>